# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_publish_metric_input import ServicePublishMetricInput

class TestServicePublishMetricInput(unittest.TestCase):
    """ServicePublishMetricInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicePublishMetricInput:
        """Test ServicePublishMetricInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServicePublishMetricInput`
        """
        model = ServicePublishMetricInput()
        if include_optional:
            return ServicePublishMetricInput(
                decr = nuon.models.metrics/decr.metrics.Decr(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, ),
                event = nuon.models.metrics/event.metrics.Event(
                    event = nuon.models.statsd/event.statsd.Event(
                        aggregation_key = '', 
                        alert_type = null, 
                        hostname = '', 
                        priority = null, 
                        source_type_name = '', 
                        tags = [
                            ''
                            ], 
                        text = '', 
                        timestamp = '', 
                        title = '', ), ),
                incr = nuon.models.metrics/incr.metrics.Incr(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, ),
                timing = nuon.models.metrics/timing.metrics.Timing(
                    name = '', 
                    tags = [
                        ''
                        ], 
                    value = 56, )
            )
        else:
            return ServicePublishMetricInput(
        )
        """

    def testServicePublishMetricInput(self):
        """Test ServicePublishMetricInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
