# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_install_component import AppInstallComponent

class TestAppInstallComponent(unittest.TestCase):
    """AppInstallComponent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstallComponent:
        """Test AppInstallComponent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstallComponent`
        """
        model = AppInstallComponent()
        if include_optional:
            return AppInstallComponent(
                component = nuon.models.app/component.app.Component(
                    app_id = '', 
                    config_versions = 56, 
                    created_at = '', 
                    created_by_id = '', 
                    dependencies = [
                        ''
                        ], 
                    id = '', 
                    name = '', 
                    status = '', 
                    status_description = '', 
                    updated_at = '', ),
                component_id = '',
                created_at = '',
                created_by_id = '',
                id = '',
                install_deploys = [
                    nuon.models.app/install_deploy.app.InstallDeploy(
                        build_id = '', 
                        component_id = '', 
                        component_name = '', 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_component_id = '', 
                        install_deploy_type = 'release', 
                        install_id = '', 
                        release_id = '', 
                        status = '', 
                        status_description = '', 
                        updated_at = '', )
                    ],
                install_id = '',
                updated_at = ''
            )
        else:
            return AppInstallComponent(
        )
        """

    def testAppInstallComponent(self):
        """Test AppInstallComponent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
